<?php

namespace App\Exports;

use App\Models\User;
use App\Helpers\LogHelper;
use App\Helpers\ExcelHelper;
use Maatwebsite\Excel\Events\AfterSheet;
use Maatwebsite\Excel\Events\BeforeSheet;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Illuminate\Contracts\Support\Responsable;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithColumnWidths;
use PhpOffice\PhpSpreadsheet\Worksheet\PageSetup;

class UsersExport implements FromCollection, WithHeadings, WithMapping, WithEvents, ShouldAutoSize, Responsable, WithColumnWidths
{
    use Exportable;

    private $usersIDs;
    /**
     * @return \Illuminate\Support\Collection
     */

    public function __construct($usersIDs)
    {
        return $this->usersIDs = $usersIDs;
    }

    public function columnWidths(): array
    {
        return [
            'A' => 1,
            'B' => 1,
            'C' => 1,
            'D' => 1,
            'E' => 1,
            'F' => 1,
            'G' => 1,
            'H' => 1,
            'I' => 1,
            'J' => 1,
            'K' => 1,
            'L' => 1,
        ];
    }

    public function registerEvents(): array
    {
        return  [
            BeforeSheet::class => function (BeforeSheet $event) {
                $event->sheet
                    ->getPageSetup()
                    ->setOrientation(PageSetup::ORIENTATION_LANDSCAPE)
                    ->setpaperSize(1);
            }
        ];
    }

    public function headings(): array
    {
        return [
            'Username',
            'Email',
            'First Name',
            'Last Name',
            'phone',
            'job description',
            'Role',
            'All Data',
        ];
    }

    public function map($users): array
    {
        $data_map = [];
        $allUserTask = [];
        foreach ($users->getUsersAllTaskAndDocuments as $getUserTask) {
            $allUserTask['title'] = $getUserTask['title'];
            $allUserTask['is_published'] = $getUserTask['is_published'];
            $allUserTask['document_id'] = $getUserTask['pivot']['document_id'];
            $allUserTask['is_read'] = $getUserTask['pivot']['is_read'];
            $allUserTask['opened_at'] = $getUserTask['pivot']['opened_at'];
            array_push($data_map, $allUserTask);
        }
        $data_map =  ExcelHelper::mapDataArray($data_map);

        $map = [
            $users->username,
            $users->email,
            $users->userData->first_name,
            $users->userData->last_name,
            $users->userData->phone,
            $users->job_description->name,
            $users->roles->pluck('name'),
        ];
        $return_data = array_merge($map, $data_map);
        //        array_push($map, $data_map);
        //      so servisna clasa da se mapira i da se prikazhe
        //        $test = ExcelHelper::mapDataArray($allUserTask);
        //        dd($data_map);
        return $return_data;
    }

    public function collection()
    {
        $message = "File for Users is exported";
        $return_data = [];
        LogHelper::logInfo($message, $return_data);
        return User::with('userData', 'authorizations', 'licenses')->find($this->usersIDs);
    }
}
