<?php

namespace App\Http\Livewire\Permissions;

use App\Helpers\LogHelper;
use Livewire\Component;
use Spatie\Permission\Models\Permission;

class AddNewPermission extends Component
{
    protected $listeners = ['showModal'];

    public $showModal = false;
    public $permissionName;

    protected $rules = [
        'permissionName' => 'required|min:3',
    ];


    public function showModal()
    {
        $this->showModal = true;
    }

    public function render()
    {
        return view('livewire.permissions.add-new-permission');
    }

    public function addPermission()
    {

        $this->validate();
        try {
            $permission = Permission::create(['guard_name' => 'web', 'name' => $this->permissionName]);
            $this->reset('permissionName');
            $this->emit('refreshComponent');
            $this->showModal = false;
            $message = __('messages.New Permission') . " $permission->name " . __('messages.is Created');
            $this->emit('successAlert', $message);

            $messageLog = "New Permission $permission->name is Created";
            $data = ['permission' => $permission];
            LogHelper::logInfo($messageLog, $data);
        } catch (\Exception $e) {
            $this->addError('permissionName', $e->getMessage());

            $message = $e->getMessage();
            $data = ['roleName' => $this->permissionName, 'error' => $e->getMessage()];
            LogHelper::logMessageError($message, $data);
        }
    }

    public function closeModal()
    {
        $this->reset();
        $this->resetErrorBag();
    }
}
