<?php

namespace App\Http\Livewire\Roles;

use App\Helpers\LogHelper;
use Livewire\Component;
use Spatie\Permission\Models\Role;

class AddNewRole extends Component
{
    protected $listeners = ['showModal'];

    public $showModal = false;
    public $roleName;

    protected $rules = [
        'roleName' => 'required|min:3',
    ];


    public function showModal()
    {
        $this->showModal = true;
    }

    public function render()
    {
        return view('livewire.roles.add-new-role');
    }

    public function addRole()
    {

        $this->validate();
        try {
            $role = Role::create(['guard_name' => 'web', 'name' => $this->roleName]);
            $this->reset('roleName');
            $this->emit('refreshComponent');
            $this->showModal = false;
            $message = __('messages.New Role') . " $role->name " . __('messages.is Created');
            $this->emit('successAlert', $message);

            $messageLog = "Нова позиција $role->name е креирана";
            $data = ['role' => $role];
            LogHelper::logInfo($messageLog, $data);
        } catch (\Exception $e) {
            $this->emit('successError', __('messages.Problem deleting, Try again later.'));
            $this->addError('roleName', $e->getMessage());
            $message = $e->getMessage();
            $data = ['roleName' => $this->roleName, 'error' => $e->getMessage()];
            LogHelper::logMessageError($message, $data);
        }
    }

    public function closeModal()
    {
        $this->reset();
        $this->resetErrorBag();
    }
}
