<?php

namespace App\Http\Livewire\Roles;

use App\Helpers\LogHelper;
use Livewire\Component;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;

class EditRole extends Component
{
    protected $listeners = ['showModal'];

    public $role;
    public $showModal = false;
    public $allPermissions;
    public $associatedPermissions;

    public function showModal(Role $role)
    {
        $this->role = $role;
        $this->associatedPermissions = $this->role->permissions->pluck('name');
        $this->showModal = true;
        $this->emit('refreshPermissionSelect');
    }

    protected $rules = [
        'role.name' => 'required|string|min:3',
    ];

    public function mount()
    {
        $this->allPermissions = Permission::all();
    }

    public function render()
    {
        return view('livewire.roles.edit-role');
    }

    public function closeModal()
    {
        $this->reset('associatedPermissions');
        $this->resetErrorBag();
    }

    public function save()
    {
        try {
            $this->validate();
            $this->role->save();
            $this->role->syncPermissions($this->associatedPermissions);
            $this->showModal = false;
            $this->emit('refreshComponent');

            $role_name = $this->role->name;
            $message = __('messages.Role') . " $role_name " . __('messages.is Edited');
            $this->emit('successAlert', $message);

            $messageLog = "Позицијата $role_name е ажурирана";
            $data = ['role_name' => $role_name, 'role' => $this->role, 'permissions' => $this->associatedPermissions];
            LogHelper::logInfo($messageLog, $data);
        } catch (\Exception $e) {
            $this->emit('successError', __('messages.Problem Editing, Try again later.'));
            $message = $e->getMessage();
            $data = ['role' => $this->role, 'error' => $e->getMessage()];
            LogHelper::logMessageError($message, $data);
        }
    }
}
