<?php

namespace App\Http\Livewire\Tables;

use Illuminate\Support\Facades\Auth;
use Rappasoft\LaravelLivewireTables\DataTableComponent;
use Rappasoft\LaravelLivewireTables\Views\Column;
use App\Models\Task;
use Illuminate\Database\Eloquent\Builder;

class DashboardTaskTable extends DataTableComponent
{
    protected $model = Task::class;

    public function configure(): void
    {
        $this->setPrimaryKey('id');
    }

    public function builder(): Builder
    {
        return Task::query()->orderBy('id', 'desc');
    }

    public function show($id)
    {
        return redirect()->route('dashboard.task.show', ['id' => $id]);
    }

    public function columns(): array
    {
        return [
            Column::make(__('messages.Id'), "id")
                ->sortable(),
            Column::make(__('messages.Title'), "title")
                ->sortable()
                ->searchable(),
            Column::make(__('messages.Description'), "description")
                ->sortable()
                ->searchable(),
            Column::make(__('messages.Due date'), "due_date")
                ->sortable(),
            Column::make(__('messages.Created at'), "created_at")
                ->sortable(),
            Column::make(__('messages.Updated at'), "updated_at")
                ->sortable(),
            Column::make(__('messages.Actions'))
                ->label(
                    function ($row, Column $column) {
                        $show = '
                            <button
                                class="inline-flex items-center text-white bg-blue-700 hover:bg-blue-800 focus:outline-none focus:ring-4 focus:ring-blue-300 font-medium rounded-full text-sm h-8 px-3 text-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800"
                                wire:click="show(' . $row->id . ')"
                                >
                                ' . __('messages.View') . '
                            </button>';
                        return $show;
                    }
                )->html(),
        ];
    }
}
