<?php

namespace App\Http\Livewire\Tasks;

use App\Helpers\DocumentHelper;
use App\Jobs\TaskAutoPublish;
use Carbon\Carbon;
use App\Models\Task;
use App\Models\User;
use Livewire\Component;
use App\Models\Document;
use App\Helpers\LogHelper;
use App\Models\JobLicense;
use App\Models\DocumentTask;
use App\Models\ReminderDate;
use Livewire\WithFileUploads;
use App\Models\JobDescription;
use App\Models\JobAuthorization;
use App\Models\UserTaskDocument;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;

class TasksForm extends Component
{
    use WithFileUploads;

    public $title, $description, $due_date, $task_id, $name, $document_id, $auto_publish;
    public $files_docs = [];
    public $existing_files_docs = [];
    public $removed_existing_docs = [];
    public $users;
    public $users_attach = [];
    public $job_descriptions;
    public $job_descriptions_attach = [];
    public $job_licenses;
    public $job_licenses_attach = [];
    public $job_authorizations;
    public $job_authorizations_attach = [];
    public $job_test_description = [];
    public $ext, $test;
    public $task;
    public $data_user_attach = [];
    public $readonly;
    public $reminders;
    public $checked_reminders = [];
    public $auto_publish_toggle = false;
    public $show_reminders = false;
    public $filterTags;

    public function toggle_reminders()
    {
        $this->set_accurate_reminders();
        $this->show_reminders = true;
    }


    public function mount($task)
    {
        if ($task) {
            $this->task_id = $task->id;
            $this->title = $task->title;
            $this->description = $task->description;
            $this->due_date = $task->due_date;
            $this->data_user_attach = $task->usersTask->pluck('id')->toArray();
            $this->checked_reminders = $task->reminder_dates->pluck('id')->toArray();
            $this->existing_files_docs = $task->documents->toArray();
            $this->task = $task;
        }
    }

    public function updatedFilesDocs()
    {
        $this->existing_files_docs = array_merge($this->existing_files_docs, $this->files_docs);
    }

    public function remove_file($key)
    {
        if (is_array($this->existing_files_docs[$key])) {
            array_push($this->removed_existing_docs, $this->existing_files_docs[$key]);
        }
        unset($this->existing_files_docs[$key]);
    }

    public function mark_document($file_id, $read)
    {

        DB::beginTransaction();
        try {
            $user_task_document = DocumentHelper::getUserTaskDocument($this->task->id, Auth::user()->id, $file_id);

            if ($read == 'is_read') {
                //                mark it as read the document
                $user_task_document->update(['is_read' => true, 'opened_at' => Carbon::now()->format('Y-m-d H:i:s')]);
            } else {
                $user_task_document->update(['is_read' => false, 'opened_at' => null]);
            }

            $update_doc_task = DocumentHelper::getUserTask($this->task->id, Auth::user()->id); # user_task data

            $check_all_documents_read = DocumentHelper::checkAllDocumentsUserTaskIsRead($this->task->id, Auth::user()->id); #user_task_documents data

            if ($check_all_documents_read) {
                $now = Carbon::now()->format('Y-m-d H:i:s');
                $update_doc_task->update(['completed' => true, 'completed_at' => $now]);
            } else {
                $update_doc_task->update(['completed' => false, 'completed_at' => null]);
            }

            DB::commit();
            if ($read == 'is_read') {
                $message = "Document is mark as read Successfully.";
                session()->flash(
                    'success',
                    $message
                );
            } else {
                $message = "Document is mark as unread Successfully.";
                session()->flash(
                    'message',
                    $message
                );
            }

            $data = ['updated_doc_task' => $update_doc_task];
            LogHelper::logInfo($message, $data);
        } catch (\Exception $e) {
            DB::rollback();
            $this->dispatchBrowserEvent('notifyUser', [
                'style' => 'danger',
                'status' =>  __('messages.Error'),
                'message' => "There was an error, please try again!"
            ]);

            $message = $e->getMessage();
            $data = ['file_id' => $file_id, 'error_message' => $message];
            LogHelper::logMessageError($message, $data);
        }
    }

    private function resetInputFields()
    {
        $this->title = '';
        $this->description = '';
        $this->due_date = '';
        $this->task_id = '';
        $this->existing_files_docs = [];
        $this->users_attach = [];
        $this->data_user_attach = [];
        $this->job_descriptions_attach = [];
        $this->job_authorizations_attach = [];
        $this->job_licenses_attach = [];
    }

    public function submit()
    {
        $this->validate([
            'title' => 'required',
            'description' => 'required',
            'due_date' => 'required|date|after_or_equal:now',
        ]);

        DB::beginTransaction();

        try {
            if ($this->task_id) {
                $task = Task::find($this->task_id);
                $task->update([
                    'title' => $this->title,
                    'description' => $this->description,
                    'due_date' => $this->due_date
                ]);
                $task->save();
            } else {
                $task = Task::create([
                    'title' => $this->title,
                    'description' => $this->description,
                    'due_date' => $this->due_date
                ]);
            }

            if ($this->existing_files_docs) {
                foreach ($this->existing_files_docs as $file) {
                    if ($file && !is_array($file)) {
                        $file_name = 'public/files/tasks/' . $task->id;
                        $name = $file->getClientOriginalName();

                        $task_files = Storage::allFiles($file_name);
                        $new_task_file = $file_name . '/' . $name;

                        $file->storeAs($file_name, $name);

                        // Check if the file already exists
                        foreach ($task_files as $task_file) {
                            if ($task_file === $new_task_file) {
                                $path_parts = pathinfo($new_task_file);
                                $name = $path_parts['filename'] . '_' . rand(1001, 9999) . '.' . $path_parts['extension'];
                                $file->storeAs($file_name, $name);
                            }
                        }

                        $document = new Document;
                        $document->name = $name;
                        $document->save();

                        $document_task = new DocumentTask;
                        $document_task->task_id = $task->id;
                        $document_task->document_id = $document->id;
                        $document_task->save();
                    }
                }
            }

            $message = $this->task ? "Task $this->title Updated Successfully." : "Task $this->title Created Successfully.";

            $this->task = $task; #da se proveri ova uste ednas
            $this->task->usersTask()->sync($this->data_user_attach);
            //            delete all data for the task and users in user_task_document table
            $this->task->usersTaskDocuments()->detach();

            foreach ($task->documents as $document) {
                foreach ($this->data_user_attach as $user_id) {
                    $user_task_documents = new UserTaskDocument;
                    $user_task_documents->task_id = $task->id;
                    $user_task_documents->document_id = $document->id;
                    $user_task_documents->user_id = $user_id;
                    $user_task_documents->save();
                }
            }

            if (count($this->removed_existing_docs) > 0) {
                foreach ($this->removed_existing_docs as $removed_file) {
                    $file_path = 'public/files/tasks/' . $this->task_id . '/' . $removed_file['name'];
                    $document_remove = Document::where('id', $removed_file['id'])->first();
                    $document_remove->delete();
                    Storage::delete($file_path);
                }
            }

            $this->task->reminder_dates()->sync($this->checked_reminders);
            DB::commit();
            if (!is_null($this->auto_publish)) {
                $auto_publisher = Carbon::parse($this->auto_publish);
                TaskAutoPublish::dispatch($this->task)->delay($auto_publisher);
            }

            $data = ['task' => $task];
            LogHelper::logInfo($message, $data);

            session()->flash(
                'message',
                $message
            );

            //            $this->resetInputFields();

            $this->reset('removed_existing_docs');
            $this->resetErrorBag();

            return redirect()->route('tasks.index');
        } catch (\Exception $e) {
            DB::rollback();
            $this->dispatchBrowserEvent('notifyUser', [
                'style' => 'danger',
                'status' =>  __('messages.Error'),
                'message' => $e->getMessage()
                // 'message' => "There was an error, updating the task, please try again!"
            ]);
            $message = $e->getMessage();
            $data = ['error_task' => $message, 'task' => $this->task];
            LogHelper::logMessageError($message, $data);
        }
    }

    public function show($id)
    {
        $task = Task::findOrFail($id);
        $this->task_id = $id;
        $this->title = $task->title;
        $this->description = $task->description;
        $this->due_date = $task->due_date;
    }

    //    public function delete($id)
    //    {
    //        $task = Task::findOrFail($id);
    //        $task_name = $task->title;
    //        $task->update(['is_published' => false]);
    //        $task->delete();
    //        $message = "Task $task_name is Deleted Successfully";
    //        $data = ['task' => $task];
    //        LogHelper::logInfo($message, $data);
    //
    //        session()->flash('message', $message);
    //    }

    public function render()
    {
        $this->filterTags = $this->filterTagsJobAuthorAndLicenc();
        $this->users = User::get();
        $this->job_descriptions = JobDescription::get();
        $this->job_licenses = JobLicense::get();
        $this->job_authorizations = JobAuthorization::get();

        return view('livewire.tasks.tasks-form');
    }

    function clear_data_from_array($array)
    {
        $remove_empty = array_filter($array); #filter empty array
        $arr_string = implode(",", $remove_empty); #concatanate arrays of string to  one string
        $cleared_data = str_replace('[', '', $arr_string); #remove brackets
        $cleared_data = str_replace(']', '', $cleared_data); #remove brackets
        $data = explode(',', $cleared_data); # make array from string
        $remove_empty_data = array_filter($data);
        $unique_data = array_unique($remove_empty_data);
        return $unique_data;
    }

    public function get_job_description_users()
    {
        $this->data_user_attach = $this->clear_data_from_array($this->job_descriptions_attach);
    }

    public function getSelectedUsers($job_description)
    {
        return $this->job_test_description[] = $job_description;
    }

    public function add_clear_users_data($user_id)
    {
        if (count($this->users_attach) > 0) {
            $array_merge = array_merge($this->data_user_attach, $this->users_attach);
            $test = array_unique($array_merge);
            $this->data_user_attach = $test;
        }
    }

    public function getAllUsersWithFilter()
    {
        $users_query = User::query();
        $users_query->with(['job_description', 'licenses', 'authorizations', 'userData']);
        if ($this->job_descriptions_attach && count($this->job_descriptions_attach) > 0) {
            foreach ($this->job_descriptions_attach as $k => $v) {
                $users_query->whereHas('job_description', function ($query) use ($v) {
                    $query->where('job_descriptions.id', $v);
                });
            }
        }

        if ($this->job_licenses_attach && count($this->job_licenses_attach) > 0) {
            foreach ($this->job_licenses_attach as $k => $v) {
                $users_query->whereHas('licenses', function ($query) use ($v) {
                    $query->where('job_licenses.id', $v);
                });
            }
        }

        if ($this->job_authorizations_attach && count($this->job_authorizations_attach) > 0) {
            foreach ($this->job_authorizations_attach as $k => $v) {
                $users_query->whereHas('authorizations', function ($query) use ($v) {
                    $query->where('job_authorizations.id', $v);
                });
            }
        }


        if (
            $this->job_authorizations_attach && count($this->job_authorizations_attach) == 0 &&
            $this->job_licenses_attach && count($this->job_licenses_attach) == 0 &&
            $this->job_descriptions_attach && count($this->job_descriptions_attach) == 0
        ) {
            $this->data_user_attach = [];
        } else {

            $users = $users_query->get()->pluck('id')->toArray();
            $this->data_user_attach = $users;
        }
    }

    public function clear_one_fields($tag)
    {

        if ($this->job_descriptions_attach) {
            foreach ($this->job_descriptions_attach as $id) {
                $jobDescModel = JobDescription::findOrFail($id);
                if ($jobDescModel->name == $tag) {
                    if (($key = array_search($jobDescModel->id, $this->job_descriptions_attach)) !== false) {
                        unset($this->job_descriptions_attach[$key]);
                    }
                }
            }
        }

        if ($this->job_licenses_attach) {
            foreach ($this->job_licenses_attach as $id) {
                $jobLicenceModel = JobLicense::findOrFail($id);
                if ($jobLicenceModel->name == $tag) {
                    if (($key = array_search($jobLicenceModel->id, $this->job_licenses_attach)) !== false) {
                        unset($this->job_licenses_attach[$key]);
                    }
                }
            }
        }



        if ($this->job_authorizations_attach) {
            foreach ($this->job_authorizations_attach as $id) {
                $jobAuthModal = JobAuthorization::findOrFail($id);
                if ($jobAuthModal->name == $tag) {
                    if (($key = array_search($jobAuthModal->id, $this->job_authorizations_attach)) !== false) {
                        unset($this->job_authorizations_attach[$key]);
                    }
                }
            }
        }

        sort($this->job_descriptions_attach);
        sort($this->job_licenses_attach);
        sort($this->job_authorizations_attach);
        $this->getAllUsersWithFilter(); # re-renders users by remaining tags

    }

    public function clear_all_fields()
    {
        $this->reset('users_attach', 'data_user_attach', 'job_descriptions_attach', 'job_authorizations_attach', 'job_licenses_attach');
    }

    public function toggle_autopublish()
    {
        $this->auto_publish_toggle = !$this->auto_publish_toggle;
    }

    private function set_accurate_reminders()
    {
        $due_date = Carbon::parse($this->due_date);
        $now = Carbon::now();
        $due_date->diffInHours($now);
        $this->reminders = ReminderDate::where('hours', '<=', $due_date->diffInHours($now))->get();
    }

    public function filterTagsJobAuthorAndLicenc()
    {

        $data = [];

        if ($this->job_descriptions_attach) {
            foreach ($this->job_descriptions_attach as $jd) {
                $jdModel = JobDescription::findOrFail($jd);
                $data[] = $jdModel->name;
            }
        }

        if ($this->job_licenses_attach) {
            foreach ($this->job_licenses_attach as $jl) {
                $jlModel = JobLicense::findOrFail($jl);
                $data[] = $jlModel->name;
            }
        }

        if ($this->job_authorizations_attach) {
            foreach ($this->job_authorizations_attach as $ja) {
                $jaModel = JobAuthorization::findOrFail($ja);
                $data[] = $jaModel->name;
            }
        }
        return $data;
    }
}
