<?php

namespace App\Http\Livewire\Users;

use App\Models\Role;
use App\Models\User;
use Livewire\Component;
use App\Helpers\LogHelper;
use Livewire\WithPagination;

class UserArchiveTable extends Component
{
    use WithPagination;

    protected $users = User::class;
    protected $listeners = ['refreshComponent' => '$refresh'];
    protected $delete;
    public $search;
    public $role;
    public $roles;

    public function mount()
    {
        $this->roles = Role::all();
    }

    public function delete($value)
    {
        $user = User::where('id', $value)->withTrashed()->first();

        if ($user->userData) {
            $user_name = $user->userData->fullName();
        } else {
            $user_name = $user->username;
        }
        $user->forceDelete();
        $this->mount();
        $this->render();

        $message = __('messages.User') . " $user_name " . __('messages.is Permanently Deleted Successfully');
        session()->flash(
            'message',
            $message
        );

        $messageLog = "Корисникоот $user_name e успешно избришан/a засекогаш";
        $data = ['user' => $user];
        LogHelper::logInfo($messageLog, $data);
    }

    public function restore($user_id)
    {
        $user = User::withTrashed()
            ->where('id', $user_id)->first();
        if ($user->userData) {
            $user_name = $user->userData->fullName();
        } else {
            $user_name = $user->username;
        }
        $user->restore();
        $this->mount();
        $this->render();

        $message = __('messages.User') . " $user_name " . __('messages.is Restored Successfully');
        session()->flash(
            'message',
            $message
        );

        $messageLog = "Корисникот $user_name e успешно обновен/а";
        $data = ['user' => $user];
        LogHelper::logInfo($messageLog, $data);
    }

    public function render()
    {
        if ($this->role) {
            $this->users = User::with('userData')
                ->onlyTrashed()
                ->where(function ($query) {
                    return $query->where('username', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%')
                        ->orWhereHas('userData', function ($query) {
                            return $query->where('first_name', 'like', '%' . $this->search . '%')
                                ->orWhere('last_name', 'like', '%' . $this->search . '%');
                        });
                })
                ->role($this->role)
                ->orderBy('deleted_at', 'desc')
                ->paginate(10);
        } else {
            $this->users = User::with('userData')
                ->onlyTrashed()
                ->where(function ($query) {
                    return $query->where('username', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%')
                        ->orWhereHas('userData', function ($query) {
                            return $query->where('first_name', 'like', '%' . $this->search . '%')
                                ->orWhere('last_name', 'like', '%' . $this->search . '%');
                        });
                })
                ->orderBy('deleted_at', 'desc')
                ->paginate(10);
        }

        return view('livewire.users.user-archive-table', ['users' => $this->users]);
    }
}
