<?php

namespace App\Http\Livewire\Users;

use App\Models\Role;
use App\Models\User;
use Livewire\Component;
use App\Helpers\LogHelper;
use App\Exports\UsersExport;
use Livewire\WithPagination;
use Maatwebsite\Excel\Facades\Excel;

class UserTable extends Component
{
    use WithPagination;

    protected $users = User::class;
    public $selectedUsers = [];
    public $selectAll = false;
    protected $listeners = ['refreshComponent' => '$refresh'];
    protected $delete;
    public $search;
    public $role;
    public $roles;

    public function mount()
    {
        $this->users = User::with('roles')->get();
        $this->selectedUsers = [];
        $this->roles = Role::all();
    }

    public function render()
    {
        if ($this->role) {
            $this->users = User::with('userData')
                ->where(function ($query) {
                    return $query->where('username', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%')
                        ->orWhereHas('userData', function ($query) {
                            return $query->where('first_name', 'like', '%' . $this->search . '%')
                                ->orWhere('last_name', 'like', '%' . $this->search . '%');
                        });
                })
                ->role($this->role)
                ->orderBy('deleted_at', 'desc')
                ->paginate(10);
        } else {
            $this->users = User::with('userData')
                ->where(function ($query) {
                    return $query->where('username', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%')
                        ->orWhereHas('userData', function ($query) {
                            return $query->where('first_name', 'like', '%' . $this->search . '%')
                                ->orWhere('last_name', 'like', '%' . $this->search . '%');
                        });
                })
                ->orderBy('deleted_at', 'desc')
                ->paginate(10);
        }

        return view('livewire.users.user-table', ['users' => $this->users]);
    }

    public function export($ext)
    {
        return Excel::download(new UsersExport($this->selectedUsers), 'users.' . $ext);
    }

    public function delete($value)
    {
        $user = User::where('id', $value)->first();
        if ($user->userData) {
            $user_name = $user->userData->fullName();
        } else {
            $user_name = $user->username;
        }
        $user->delete();
        $this->mount();
        $this->render();

        $message = __('messages.User') . " $user_name " . __('messages.is Archived Successfully');
        session()->flash(
            'message',
            $message
        );
        $messageLog = " Корисникот $user_name е успешно избришан/а";
        $data = ['user' => $user];
        LogHelper::logInfo($messageLog, $data);
    }

    public function clear_all_fields()
    {
        $this->selectedUsers = [];
        $this->selectAll = false;
    }

    public function toggleAllCheckboxes()
    {
        if ($this->selectAll) {
            if ($this->role) {
                $this->selectedUsers = User::where('username', 'like', '%' . $this->search . '%')
                    ->orWhere('email', 'like', '%' . $this->search . '%')
                    ->role($this->role)
                    ->get()->pluck('id');
            } else {
                $this->selectedUsers = User::where('username', 'like', '%' . $this->search . '%')
                    ->orWhere('email', 'like', '%' . $this->search . '%')
                    ->get()->pluck('id');
            }
            $this->selectAll = true;
        } else {
            $this->selectedUsers = [];
            $this->selectAll = false;
        }
    }

    public function changeRole()
    {
        $this->selectedUsers = [];
        $this->selectAll = false;
    }
}
